searchProfile(q, language = NULL, results = 1, nextToken = NULL, cr = 1)results argument will try
to get that many results. But there may be less (because
Google could not find more) or more (because Google is
organizing results on pages and it would be a waste to
discard them automatically). If you really depend on
getting not more rows than you expected, use standard
selection (i.e. [) to trim the results.