harvestProfile: Retrieve the profile of Google+ users
Description
This function retrieves the profile of one or more Google+
user(s). Google calls this `get people`. The results are
returned in a data frame. See Details.
Usage
harvestProfile(id)
Arguments
id
A character vector of the Google+ user ID(s).
Value
The function returns a data frame with all available
information with one row per user ID. See Details
for a description of its columns.
Details
The following fields will be filled with data (if
available) or NA otherwise: [object Object],[object Object],[object Object],[object Object],[object Object],[object Object],[object Object],[object Object],[object Object],[object Object],[object Object],[object Object],[object Object],[object Object],[object Object],[object Object],[object Object],[object Object],[object Object]
See Also
Google+ API documentation:
https://developers.google.com/+/api/latest/people/get